@@ -1206,7 +1206,7 @@ int LibRaw::open_datastream(LibRaw_abstract_datastream *stream)
 	  INT64 profile_sz = MIN(INT64(C.profile_length), ID.input->size() - ID.profile_offset);
 	  if (profile_sz > 0LL && profile_sz < LIBRAW_MAX_PROFILE_SIZE_MB * 1024LL * 1024LL)
 	  {
-        C.profile = malloc(size_t(profile_sz));
+        C.profile = calloc(size_t(profile_sz),1);
         ID.input->seek(ID.profile_offset, SEEK_SET);
         ID.input->read(C.profile, size_t(profile_sz), 1);
 	  }
